#
# spec file for package python-watchfiles
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           python-watchfiles
Version:        0.19.0
Release:        1.2
Summary:        File watching and code reload in python
License:        MIT
URL:            https://github.com/samuelcolvin/watchfiles
Source0:        https://github.com/samuelcolvin/watchfiles/archive/refs/tags/v%{version}.tar.gz#/watchfiles-%{version}-gh.tar.gz
Source1:        vendor.tar.xz
# PATCH-FEATURE-OPENSUSE cargo_config.patch code@bnavigator.de -- replace cargo config
Patch0:         cargo_config.patch
BuildRequires:  %{python_module anyio >= 3.0.0}
BuildRequires:  %{python_module base >= 3.7}
BuildRequires:  %{python_module pip}
BuildRequires:  cargo-packaging
BuildRequires:  dos2unix
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
BuildRequires:  python3-maturin >= 0.14.16
Requires:       python-anyio >= 3.0.0
Requires(post): update-alternatives
Requires(postun):update-alternatives
# SECTION test
BuildRequires:  %{python_module dirty-equals}
BuildRequires:  %{python_module pytest-mock}
BuildRequires:  %{python_module pytest-pretty}
BuildRequires:  %{python_module pytest-timeout}
BuildRequires:  %{python_module pytest}
# /SECTION
%python_subpackages

%description
A package for file watching and code reload in python.

This package was previously named "watchgod".

%prep
%autosetup -p1 -n watchfiles-%{version} -a1
# Need to replace version because we build from github archive
sed -i 's/version = "0.0.0"/version = "%{version}"/' Cargo.toml

%build
# one universal abi3 wheel for all flavors
maturin build -r --compatibility linux -o wheels

%install
%pyproject_install wheels/watchfiles-%{version}*.whl
%python_clone -a %{buildroot}%{_bindir}/watchfiles
%python_expand %fdupes %{buildroot}%{$python_sitearch}

%check
mv watchfiles watchfiles.movedaway
%pytest_arch

%post
%python_install_alternative watchfiles

%postun
%python_uninstall_alternative watchfiles

%files %{python_files}
%license LICENSE
%doc README.md docs/*
%python_alternative %{_bindir}/watchfiles
%{python_sitearch}/watchfiles
%{python_sitearch}/watchfiles-%{version}*-info

%changelog
* Thu May 11 2023 Ben Greiner <code@bnavigator.de>
- Update to v0.19.0
  * Better error on OS watcher limit by @samuelcolvin in #208
  * Switch flake8->ruff by @TheoBabilon in #212
  * Simplify Change.raw_str() by @davidbrochart in #211
  * Upgrade maturin to 0.14 by @messense in #214
  * Fix bug in RustNotify causing RuntimeError: Already borrowed on
    exit/signal by @vrslev in #221
  * Update pyo3 to 0.18.2 by @messense in #222
- Release v0.18.1
  * uprev pyo3, relax anyio constraint by @samuelcolvin in #203
  * switch pytest-sugar -> pytest-pretty by @samuelcolvin in #204
- Release v0.18.0
  * Force polling on WSL #194
  * increase default polling delay to 300ms #196
- Release v0.17.0
  * uprev notify to 5.0.0-pre.16, #182
  * Add option to disable recursion by @bvanelli in #183
  * upgrade to notify 5.0.0, #184
  * Lock all requirements, #185
- Release v0.16.0
  * make RustNotify a context manager and kill the thread on exit
    [#164]
  * Support WATCHFILES_FORCE_POLLING env var #170
  * fallback to poll watcher on OS Error 38 #172
  * --verbose argument and improve bug template #174
- Switch from PyPI sdist to github archive: docs missing, required
  for tests
* Mon Jul 18 2022 Ben Greiner <code@bnavigator.de>
- Initial specfile fo v0.15.0
- Replaces python-watchgod
- Required by python-uvicorn
